Package: XLConnect
Type: Package
Title: Excel Connector for R
Version: 1.3.0
Authors@R: c(person("Mirai Solutions GmbH", role = "aut",
                    email = "xlconnect@mirai-solutions.com"),
             person("Martin", "Studer", role = "cre",
                    email = "martin.studer@mirai-solutions.com",
                    comment = c(ORCID = "0009-0004-8250-7303")),
             person("The Apache Software Foundation", role = c("ctb", "cph"),
                    comment = "Apache POI"),
             person("Graph Builder", role = c("ctb", "cph"),
                   comment = "Curvesapi Java library"),
             person("Brett Woolridge", role = c("ctb", "cph"),
                   comment = "SparseBitSet Java library"))
URL: https://mirai-solutions.ch
        https://github.com/miraisolutions/xlconnect
BugReports: https://github.com/miraisolutions/xlconnect/issues
SystemRequirements: Java (>= 8)
Depends: R (>= 3.6.0)
Imports: methods, rJava (>= 1.0-1)
Suggests: lattice, ggplot2 (>= 0.9.3), zoo, testthat, withr
Description: Provides comprehensive functionality to read, write and format Excel data.
License: GPL-3
Copyright: See file COPYRIGHTS
LazyData: yes
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-02-24 07:37:25 UTC; mstuder
Author: Mirai Solutions GmbH [aut],
  Martin Studer [cre] (ORCID: <https://orcid.org/0009-0004-8250-7303>),
  The Apache Software Foundation [ctb, cph] (Apache POI),
  Graph Builder [ctb, cph] (Curvesapi Java library),
  Brett Woolridge [ctb, cph] (SparseBitSet Java library)
Maintainer: Martin Studer <martin.studer@mirai-solutions.com>
Repository: CRAN
Date/Publication: 2026-02-24 08:20:02 UTC
Built: R 4.6.0; ; 2026-04-25 23:11:26 UTC; unix
