# XLConnect requires rJava
import(methods)
import(rJava)
importFrom(utils, packageDescription)
importFrom(utils, browseURL)
importFrom(utils, download.file)

# XLConnect exports the following S4 classes & methods
exportClasses(workbook, cellstyle)
exportMethods(
	addImage,
	appendNamedRegion,
	appendWorksheet,
	clearNamedRegion,
	clearRange,
	clearRangeFromReference,
	clearSheet,
	cloneSheet,
	createCellStyle,
	createName,
	createFreezePane,
	createSheet,
	createSplitPane,
	existsCellStyle,
	existsName,
	existsSheet,
	getActiveSheetIndex,
	getActiveSheetName,
	getBoundingBox,
	getCellStyle,
	getCellStyleForType,
	getCellFormula,
	getDefinedNames,
	getForceFormulaRecalculation,
	getLastRow,
	getLastColumn,
	getOrCreateCellStyle,
	getReferenceFormula,
	getReferenceCoordinates,
	getReferenceCoordinatesForName,
	getReferenceCoordinatesForTable,
	getSheetPos,
	getSheets,
	getTables,
	hideSheet,
	isSheetHidden,
	isSheetVeryHidden,
	isSheetVisible,
	mergeCells,
	onErrorCell,
	print,
	readNamedRegion,
	readTable,
	readWorksheet,
	removeName,
	removePane,
	removeSheet,
	renameSheet,
	saveWorkbook,
	setActiveSheet,
	setAutoFilter,
	setBorder,
	setCellStyle,
	setCellStyleForType,
	setCellFormula,
	setColumnWidth,
	setDataFormat,
	setDataFormatForType,
	setFillBackgroundColor,
	setFillForegroundColor,
	setFillPattern,
	setForceFormulaRecalculation,
	setHyperlink,
	setMissingValue,
	setRowHeight,
	setSheetColor,
	setSheetPos,
	setStyleAction,
	setStyleNamePrefix,
	setWrapText,
	show,
	summary,
	unhideSheet,
	unmergeCells,
	writeNamedRegion,
	writeWorksheet,
	"$"
)

# XLConnect exports the following functions & variables
export(
	aref,
	aref2idx,
	col2idx,
	configurePOI,
	cref2idx,
	extractSheetName,
	idx2aref,
	idx2col,
	idx2cref,
	mirai,
	loadWorkbook,
	normalizeDataframe,
	readNamedRegionFromFile,
	readWorksheetFromFile,
	writeNamedRegionToFile,
	writeWorksheetToFile,
	xlcDump,
	xlcEdit,
	xlcFreeMemory,
	xlcMemoryReport,
	xlcRestore,
	XLC
)

# XLConnect exports the following S3 methods
S3method(print, mirai)
S3method(with, workbook)

